spiderfetch
===========

.. image:: https://badge.fury.io/py/nametrans.png
        :target: https://badge.fury.io/py/nametrans

.. image:: https://travis-ci.org/numerodix/nametrans.png?branch=master
    :target: https://travis-ci.org/numerodix/nametrans


Install
-------

.. code:: bash

    $ pip install nametrans
    $ nametrans
